import * as adopted_style_sheets from 'adopted-style-sheets';
import { Generic, Theme } from 'adopted-style-sheets';
export { default as colorRgba } from 'color-rgba';
import { RGB } from 'color-convert/conversions';
export { default as rgbaConvert } from 'rgba-convert';

type AccessKeyPropType = string;
type PropAccessKey = {
    accessKey: AccessKeyPropType;
};
declare const validateAccessKey: (component: Generic.Element.Component, value?: AccessKeyPropType) => void;

type HintOptions = {
    details?: unknown[];
    force?: boolean;
};
declare const a11yHint: (msg: string, options?: HintOptions) => void;
declare const devHint: (msg: string, options?: HintOptions) => void;
declare const devWarning: (msg: string, options?: HintOptions) => void;
declare const featureHint: (msg: string, done?: boolean, options?: HintOptions) => void;
declare const uiUxHint: (msg: string, options?: HintOptions) => void;
declare const a11yHintDisabled: () => void;
declare const a11yHintLabelingLandmarks: (value: unknown) => void;
declare const uiUxHintMillerscheZahl: (className: string, length?: number) => void;

declare const getContrastYIQ: (r: number, g: number, b: number) => number;
type ColorPair$1<T> = {
    background: T;
    foreground: T;
};
type ColorContrast<T> = ColorPair$1<T> & {
    contrast: number;
};
declare const calcColorContrast: (baseColor: RGB, contrastColor: RGB, ratio: number, dir?: number) => ColorContrast<RGB>;
declare const getColorContrast: (baseColor: RGB, contrastColor: RGB, ratio: number, dir?: number) => ColorContrast<RGB>;
declare const createContrastColorPair: (color: string | ColorPair$1<string>, contrastRatio?: number) => ColorContrast<string>;

type GetModeFn = () => boolean;
declare const getWindow: () => Window;
declare const setWindow: (value: Window) => void;
declare const getDocument: () => Document;
declare const setDocument: (value: Document) => void;
declare const getDevMode: () => boolean;
declare const setDevMode: (value: boolean) => void;
declare const getExperimentalMode: () => boolean;
declare const setExperimentalMode: (value: boolean) => void;
declare const getColorContrastAnalysis: () => boolean;
declare const setColorContrastAnalysis: (value: boolean) => void;
type LogShieldOptions = {
    classifier?: string;
    forceLog?: boolean;
    overwriteStyle?: string;
};
declare class Logger {
    private readonly label;
    private readonly devMode;
    constructor(label: string, devMode: GetModeFn);
    debug(msg: unknown | unknown[], options?: LogShieldOptions): void;
    info(msg: unknown | unknown[], options?: LogShieldOptions): void;
    trace(msg: unknown | unknown[], options?: LogShieldOptions): void;
    warn(msg: unknown | unknown[], options?: LogShieldOptions): void;
    error(msg: unknown | unknown[], options?: LogShieldOptions): void;
    throw(msg: unknown | unknown[], options?: LogShieldOptions): void;
}
declare const Log: Logger;

type Stringified<T> = string | T;

type StencilUnknown = object | string | number | boolean | null | undefined;

declare const objectObjectHandler: (value: unknown, cb: () => void) => void;
declare const emptyStringByArrayHandler: (value: unknown, cb: () => void) => void;
declare const setEventTarget: (event: Event, target?: HTMLElement) => void;
type SetStateHooks = {
    afterPatch?: Generic.Element.StateHooksCallback;
    beforePatch?: Generic.Element.NextStateHooksCallback;
};
declare const setState: <T>(component: Generic.Element.Component, propName: string, value?: T | null | undefined, hooks?: SetStateHooks) => void;
type WatchOptions = {
    defaultValue?: unknown;
    hooks?: SetStateHooks;
    required?: boolean;
};
type WatchBooleanOptions = WatchOptions & {
    defaultValue?: boolean | null;
};
type WatchStringOptions = WatchOptions & {
    defaultValue?: string | null;
    maxLength?: number;
    minLength?: number;
};
type WatchNumberOptions = WatchOptions & {
    defaultValue?: number | null;
    min?: number;
    max?: number;
};
declare function watchValidator<T>(component: Generic.Element.Component, propName: string, validationFunction: (value?: T) => boolean, requiredGeneric: Set<string | null | undefined>, value?: T, options?: WatchOptions): void;
declare const watchBoolean: (component: Generic.Element.Component, propName: string, value?: boolean, options?: WatchBooleanOptions) => void;
declare const watchString: (component: Generic.Element.Component, propName: string, value?: string, options?: WatchStringOptions) => void;
declare const watchNumber: (component: Generic.Element.Component, propName: string, value?: number, options?: WatchNumberOptions) => void;
declare const watchJsonArrayString: <T>(component: Generic.Element.Component, propName: string, itemValidation: (item: T) => boolean, value?: Stringified<T[]>, arrayValidation?: (items: T[]) => boolean, options?: WatchOptions) => void;
declare const mapString2Unknown: (value: StencilUnknown) => StencilUnknown;
declare const stringifyJson: (value: unknown) => string;
declare const parseJson: <T>(value: unknown) => T;
declare const mapBoolean2String: (value?: boolean) => string | undefined;
declare const mapStringOrBoolean2String: (value?: string | boolean) => string | undefined;
declare const koliBriQuerySelector: <T extends Element>(selector: string, node?: Document | HTMLElement | ShadowRoot) => T | null;
declare const koliBriQuerySelectorAll: <T extends Element>(selector: string, node?: Document | HTMLElement | ShadowRoot) => T[];
interface A11yColorContrast {
    backgroundColor: string;
    color: string;
    domNode: HTMLElement | HTMLSlotElement;
    level: string;
    score: number;
}
declare const koliBriA11yColorContrast: (domNode: HTMLElement, a11yColorContrast?: A11yColorContrast) => A11yColorContrast;
declare const koliBriQuerySelectorColors: (selector: string, a11yColorContrast?: A11yColorContrast) => A11yColorContrast;
declare class KoliBriUtils {
    private static executionLock;
    private static cache;
    static queryHtmlElementColors(targetNode: HTMLElement, a11yColorContrast: A11yColorContrast, recursion?: boolean, log?: boolean): A11yColorContrast | null;
}
declare class KoliBriDevHelper {
    static readonly patchTheme: (name: string, map: Generic.Theming.Map<string, string>, options?: Generic.Theming.PatchOptions | undefined, registerOptions?: adopted_style_sheets.RegisterOptions | undefined) => string;
    static readonly patchThemeTag: (themeName: string, tagName: "GLOBAL" | "PROPERTIES" | `${Uppercase<string>}-${Uppercase<string>}`, css: string, options?: Generic.Theming.PatchOptions | undefined) => void;
    static readonly querySelector: <T extends Element>(selector: string, node?: Document | HTMLElement | ShadowRoot | undefined) => T | null;
    static readonly querySelectorAll: <T extends Element>(selector: string, node?: Document | HTMLElement | ShadowRoot | undefined) => T[];
    static readonly stringifyJson: (value: unknown) => string;
}

declare const propagateFocus: <H extends HTMLElement, R extends HTMLElement>(host?: H, ref?: R) => void;
declare const PROCESS_ENVS: readonly ["development", "production", "test"];
type ProcessEnv = (typeof PROCESS_ENVS)[number];
declare let processEnv: ProcessEnv;
declare const handleSlotContent: (hostRef: HTMLElement, slotRef: HTMLElement, slotName: string) => void;
declare const showExpertSlot: (label: unknown) => boolean;

type ActivePropType = boolean;
type PropActive = {
    active: ActivePropType;
};
declare const validateActive: (component: Generic.Element.Component, value: ActivePropType, options?: WatchBooleanOptions) => void;

type AdjustHeightPropType = boolean;
type PropAdjustHeight = {
    adjustHeight: AdjustHeightPropType;
};
declare const validateAdjustHeight: (component: Generic.Element.Component, value?: AdjustHeightPropType) => void;

type AlertPropType = boolean;
type PropAlert = {
    alert: AlertPropType;
};
declare const validateAlert: (component: Generic.Element.Component, value?: AlertPropType) => void;

declare const horizontalAlignOptions: readonly ["left", "right"];
type HorizontalAlign = (typeof horizontalAlignOptions)[number];
declare const verticalAlignOptions: readonly ["top", "bottom"];
type VerticalAlign = (typeof verticalAlignOptions)[number];
declare const alignPropTypeOptions: readonly ["left", "right", "top", "bottom"];
type AlignPropType = HorizontalAlign | VerticalAlign;
type PropAlign = {
    align: AlignPropType;
};
declare const validateAlign: (component: Generic.Element.Component, value?: AlignPropType) => void;

type AlternativeButtonLinkRolePropType = 'button' | 'link' | 'tab';
type PropAlternativeButtonLinkRole = {
    role: AlternativeButtonLinkRolePropType;
};
declare const validateAlternativeButtonLinkRole: (component: Generic.Element.Component, value?: AlternativeButtonLinkRolePropType) => void;

type AriaControlsPropType = string;
type PropAriaControls = {
    ariaControls: AriaControlsPropType;
};
declare const validateAriaControls: (component: Generic.Element.Component, value?: AriaControlsPropType) => void;

declare const ariaCurrentValuePropTypeOptions: readonly ["date", "location", "page", "step", "time", "true", "false"];
type AriaCurrentValuePropType = (typeof ariaCurrentValuePropTypeOptions)[number];
type PropAriaCurrentValue = {
    ariaCurrentValue: AriaCurrentValuePropType;
};
declare const validateAriaCurrentValue: (component: Generic.Element.Component, value?: AriaCurrentValuePropType) => void;

type AriaExpandedPropType = boolean;
type PropAriaExpanded = {
    ariaExpanded: AriaExpandedPropType;
};
declare const validateAriaExpanded: (component: Generic.Element.Component, value?: AriaExpandedPropType) => void;

type AriaSelectedPropType = boolean;
type PropAriaSelected = {
    ariaSelected: AriaSelectedPropType;
};
declare const validateAriaSelected: (component: Generic.Element.Component, value?: boolean) => void;

declare enum Events {
    onBlur = "onBlur",
    onChange = "onChange",
    onClick = "onClick",
    onDblClick = "onDblClick",
    onFocus = "onFocus",
    onInput = "onInput",
    onKeyDown = "onKeyDown",
    onKeyPress = "onKeyPress",
    onKeyUp = "onKeyUp",
    onMouseDown = "onMouseDown",
    onMouseMove = "onMouseMove",
    onMouseOut = "onMouseOut",
    onMouseOver = "onMouseOver",
    onMouseUp = "onMouseUp",
    onReset = "onReset",
    onSelect = "onSelect",
    onSort = "onSort",
    onSubmit = "onSubmit"
}

type Callback<T> = (event: T) => void;
type EventCallback<E extends Event> = Callback<E>;
type EventValueCallback<E extends Event, V> = (event: E, value: V) => void;
type EventValueOrEventCallback<E extends Event, V> = EventValueCallback<E, V> | EventCallback<E>;

type ButtonCallbacksPropType<T> = {
    [Events.onClick]?: EventValueOrEventCallback<MouseEvent, T>;
    [Events.onMouseDown]?: EventCallback<MouseEvent>;
};
type PropButtonCallbacks<T> = {
    on: ButtonCallbacksPropType<T>;
};
declare const validateButtonCallbacks: (component: Generic.Element.Component, value?: ButtonCallbacksPropType<StencilUnknown>) => void;

declare const buttonTypePropTypeOptions: readonly ["button", "reset", "submit"];
type ButtonTypePropType = (typeof buttonTypePropTypeOptions)[number];
type PropButtonType = {
    type: ButtonTypePropType;
};
declare const validateButtonType: (component: Generic.Element.Component, value?: ButtonTypePropType) => void;

declare const buttonVariantPropTypeOptions: readonly ["primary", "secondary", "normal", "tertiary", "danger", "ghost", "custom"];
type ButtonVariantPropType = (typeof buttonVariantPropTypeOptions)[number];
type PropButtonVariant = {
    variant: ButtonVariantPropType;
};
declare const validateButtonVariant: (component: Generic.Element.Component, value?: ButtonVariantPropType) => void;

type CheckedPropType = boolean;
type PropChecked = {
    checked: CheckedPropType;
};
declare const validateChecked: (component: Generic.Element.Component, value?: CheckedPropType) => void;

type CollapsiblePropType = boolean;
type PropCollapsible = {
    collapsible: CollapsiblePropType;
};
declare const validateCollapsible: (component: Generic.Element.Component, value?: CollapsiblePropType) => void;

type RequiredButtonProps$1 = PropLabel & PropButtonCallbacks<StencilUnknown>;
type RequiredLinkProps = PropHref;
type RequiredTextProps = PropLabel;
type OptionalButtonOrLinkOrTextProps = PropHideLabel & {
    active: boolean;
} & PropIcons & PropLinkTarget;
type OptionalButtonProps$1 = OptionalButtonOrLinkOrTextProps & {
    disabled: boolean;
};
type OptionalButtonOrLinkOrTextWithChildrenProps = OptionalButtonOrLinkOrTextProps & {
    children: ButtonOrLinkOrTextWithChildrenProps[];
} & PropLabel;
type OptionalButtonWithChildrenProps = OptionalButtonProps$1 & {
    children: ButtonOrLinkOrTextWithChildrenProps[];
};
type ButtonWithChildrenProps = Generic.Element.Members<RequiredButtonProps$1, OptionalButtonWithChildrenProps>;
type LinkWithChildrenProps = Generic.Element.Members<RequiredLinkProps, OptionalButtonOrLinkOrTextWithChildrenProps>;
type TextWithChildrenProps = Generic.Element.Members<RequiredTextProps, OptionalButtonOrLinkOrTextWithChildrenProps>;
type ButtonOrLinkOrTextWithChildrenProps = ButtonWithChildrenProps | LinkWithChildrenProps | TextWithChildrenProps;

type AnyIconFontClass = string;
type KoliBriCustomIcon = {
    icon: AnyIconFontClass;
    label?: string;
    style?: Record<string, string>;
};
type IconOrIconClass = AnyIconFontClass | KoliBriCustomIcon;
type KoliBriHorizontalIcons = {
    right?: IconOrIconClass;
    left?: IconOrIconClass;
};
type KoliBriVerticalIcons = {
    top?: IconOrIconClass;
    bottom?: IconOrIconClass;
};
type KoliBriAllIcons = KoliBriHorizontalIcons & KoliBriVerticalIcons;
type KoliBriIconsProp = AnyIconFontClass | KoliBriAllIcons;
type KoliBriIconsState = KoliBriAllIcons;

declare const inputTypeOnOffOptions: readonly ["on", "off"];
type InputTypeOnOff = (typeof inputTypeOnOffOptions)[number];
type InputTypeOnBlur = {
    [Events.onBlur]?: EventCallback<Event>;
};
type InputTypeOnClick = {
    [Events.onClick]?: EventCallback<Event>;
};
type InputTypeOnChange = {
    [Events.onChange]?: EventValueOrEventCallback<Event, unknown>;
};
type InputTypeOnFocus = {
    [Events.onFocus]?: EventCallback<Event>;
};
type InputTypeOnInput = {
    [Events.onInput]?: EventValueOrEventCallback<Event, unknown>;
};
type Option<T> = {
    disabled?: boolean;
    label: string | number;
    value: T;
};
type Optgroup<T> = {
    disabled?: boolean;
    label: string;
    options: Option<T>[];
};
type SelectOption<T> = Option<T> | Optgroup<T>;
type InputTypeOnDefault = InputTypeOnBlur & InputTypeOnClick & InputTypeOnChange & InputTypeOnFocus & InputTypeOnInput;

declare const inputDateTypeOptions: readonly ["date", "datetime-local", "month", "time", "week"];
type InputDateType = (typeof inputDateTypeOptions)[number];
type OptionalInputProps<T> = {
    accessKey: string;
    alert: boolean;
    autoComplete: InputTypeOnOff;
    disabled: boolean;
    error: string;
    hideLabel: boolean;
    hint: string;
    icons: Stringified<KoliBriHorizontalIcons>;
    max: T;
    min: T;
    name: string;
    on: InputTypeOnDefault;
    readOnly: boolean;
    required: boolean;
    smartButton: Stringified<ButtonProps>;
    step: number;
    tabIndex: number;
    touched: boolean;
    value: T | null;
};

declare const inputTextTypeOptions: readonly ["text", "search", "url", "tel"];
type InputTextType = (typeof inputTextTypeOptions)[number];

type Hour = `${number}`;
type Minute = `${number}`;
type Second = `${number}`;
type Year = `${number}`;
type Month = `${number}`;
type Day = `${number}`;
type CalendarWeek = `${number}`;
type IsoDate = `${Year}-${Month}-${Day}`;
type IsoTime = `${Hour}:${Minute}` | `${Hour}:${Minute}:${Second}`;
type IsoLocalDateTime = `${IsoDate}T${IsoTime}`;
type IsoMonth = `${Year}-${Month}`;
type IsoWeek = `${Year}-W${CalendarWeek}`;
type Iso8601 = IsoDate | IsoTime | IsoLocalDateTime | IsoMonth | IsoWeek;

type KoliBriModalEventCallbacks = {
    onClose?: () => void;
};

declare const orientationOptions: readonly ["horizontal", "vertical"];
type Orientation = (typeof orientationOptions)[number];

declare enum KoliBriProgressVariantEnum {
    'bar' = "bar",
    'cycle' = "cycle"
}
type KoliBriProgressVariantType = `${KoliBriProgressVariantEnum}`;

type W3CInputValue = string | number;

type KoliBriTableRender = <T>(domNode: HTMLElement, cell: KoliBriTableCell, tupel: T, data: T[]) => string | void;
type KoliBriTableCellTextAlign = 'center' | 'left' | 'right' | 'justify';
type KoliBriSortDirection = 'ASC' | 'DESC' | 'NOS';
type KoliBriTableDataType = Record<string, unknown>;
type KoliBriTableCell = {
    asTd?: boolean;
    colSpan?: number;
    label: string;
    render?: KoliBriTableRender;
    rowSpan?: number;
    textAlign?: KoliBriTableCellTextAlign;
    width?: string;
};
type KoliBriTableHeaderCell = KoliBriTableCell & {
    key?: string;
    sortDirection?: KoliBriSortDirection;
};

type CharacteristicColors = {
    primary: string;
    secondary: string;
    neutral: string;
};
type ColorPair = {
    backgroundColor: string;
    foregroundColor: Stringified<CharacteristicColors>;
};
type PropColor = ColorPair;
declare const validateColor: (component: Generic.Element.Component, value?: Stringified<PropColor>, options?: WatchOptions) => void;
declare const handleColorChange: (value: unknown) => ColorPair;

type CustomClassPropType = string;
type PropCustomClass = {
    customClass: CustomClassPropType;
};
declare const validateCustomClass: (component: Generic.Element.Component, value?: CustomClassPropType) => void;

type DisabledPropType = boolean;
type PropDisabled = {
    disabled: DisabledPropType;
};
declare const validateDisabled: (component: Generic.Element.Component, value?: DisabledPropType) => void;

type DownloadPropType = string;
type PropDownload = {
    download?: DownloadPropType;
};
declare const validateDownload: (component: Generic.Element.Component, value?: DownloadPropType) => void;

type ErrorListPropType = {
    message: string;
    selector: string;
};
type PropErrorList = {
    errorList: ErrorListPropType[];
};
declare const validateErrorList: (component: Generic.Element.Component, value?: ErrorListPropType[]) => void;

type HasCloserPropType = boolean;
type PropHasCloser = {
    hasCloser: HasCloserPropType;
};
declare const validateHasCloser: (component: Generic.Element.Component, value?: HasCloserPropType) => void;

type HasCompactButtonPropType = boolean;
type PropHasCompactButton = {
    hasCompactButton: HasCompactButtonPropType;
};
declare const validateHasCompactButton: (component: Generic.Element.Component, value?: HasCompactButtonPropType) => void;

type HasCounterPropType = boolean;
type PropHasCounter = {
    hasCounter: HasCounterPropType;
};
declare const validateHasCounter: (component: Generic.Element.Component, value?: HasCounterPropType) => void;

type HasIconsWhenExpandedPropType = boolean;
type PropHasIconsWhenExpanded = {
    hasIconsWhenExpanded: HasIconsWhenExpandedPropType;
};
declare const validateHasIconsWhenExpanded: (component: Generic.Element.Component, value?: HasIconsWhenExpandedPropType) => void;

declare const headingVariantPropTypeOptions: readonly ["h1", "h2", "h3", "h4", "h5", "h6", "strong"];
type HeadingVariantPropType = (typeof headingVariantPropTypeOptions)[number];
type PropHeadingVariant = {
    variant: HeadingVariantPropType;
};
declare const validateHeadingVariant: (component: Generic.Element.Component, value?: HeadingVariantPropType) => void;

type HideErrorPropType = boolean;
type PropHideError = {
    hideError: HideErrorPropType;
};
declare const validateHideError: (component: Generic.Element.Component, value?: HideErrorPropType, options?: WatchBooleanOptions) => void;

type HideLabelPropType = boolean;
type PropHideLabel = {
    hideLabel: HideLabelPropType;
};
declare const validateHideLabel: (component: Generic.Element.Component, value?: HideLabelPropType, options?: WatchBooleanOptions) => void;

type HrefPropType = string;
type PropHref = {
    href: HrefPropType;
};
type HrefProp = Generic.Element.Members<PropHref, unknown>;
declare const validateHref: (component: Generic.Element.Component, value?: HrefPropType, options?: WatchStringOptions) => void;

type IconsPropType = Stringified<KoliBriIconsProp>;
type PropIcons = {
    icons: IconsPropType;
};
declare const mapIconProp2State: (icon: KoliBriIconsProp) => KoliBriIconsState;
declare const isIcon: (value?: unknown) => boolean;
declare const validateIcons: (component: Generic.Element.Component, value?: IconsPropType, options?: WatchOptions) => void;

type IdPropType = string;
type PropId = {
    id: IdPropType;
};
declare const validateId: (component: Generic.Element.Component, value?: IdPropType) => void;

type ImageSourcePropType = string;
type PropImageSource = {
    src: ImageSourcePropType;
};
declare const validateImageSource: (component: Generic.Element.Component, value?: ImageSourcePropType, options?: WatchStringOptions) => void;

type IndeterminatePropType = boolean;
type PropIndeterminate = {
    indeterminate: IndeterminatePropType;
};
declare const validateIndeterminate: (component: Generic.Element.Component, value?: IndeterminatePropType) => void;

declare const headingLevelOptions: readonly [0, 1, 2, 3, 4, 5, 6];
type HeadingLevel = (typeof headingLevelOptions)[number];
declare function hasEnoughReadableChars(str: string, min?: number): boolean;
declare function containsOnlyNumbers(str: string): boolean;
type LabelPropType = string;
type LabelWithExpertSlotPropType = LabelPropType | '';
type PropLabel = {
    label: LabelPropType;
};
type PropLabelWithExpertSlot = {
    label: LabelWithExpertSlotPropType;
};
type LabelProp = Generic.Element.Members<PropLabel, unknown>;
declare const validateLabel: (component: Generic.Element.Component, value?: LabelPropType, options?: WatchStringOptions) => void;
declare const validateLabelWithExpertSlot: (component: Generic.Element.Component, value?: LabelPropType, options?: WatchStringOptions) => void;

type LinkOnCallbacksPropType = {
    [Events.onClick]?: EventValueOrEventCallback<Event, string>;
};
type PropLinkOnCallbacks = {
    on: LinkOnCallbacksPropType;
};
declare const validateLinkCallbacks: (component: Generic.Element.Component, value?: LinkOnCallbacksPropType) => void;

type LinkTargetPropType = '_blank' | '_parent' | '_self' | '_top' | string;
type PropLinkTarget = {
    target: LinkTargetPropType;
};
declare const validateLinkTarget: (component: Generic.Element.Component, value?: LinkTargetPropType) => void;

declare const loadingOptions: readonly ["eager", "lazy"];
type Loading = (typeof loadingOptions)[number];
declare function validateLoading(component: Generic.Element.Component, value?: Loading): void;

type RowsPropType = number;
type PropRows = {
    rows: RowsPropType;
};
declare const validateRows: (component: Generic.Element.Component, value?: RowsPropType) => void;

type MaxPropType = number;
type PropMax = {
    max: MaxPropType;
};
declare const validateMax: (component: Generic.Element.Component, value?: RowsPropType, options?: WatchNumberOptions) => void;

type MsgPropType = AlertProps & {
    _description: string;
};
type PropMsg = {
    msg: MsgPropType;
};
declare const validateMsg: (component: Generic.Element.Component, value?: MsgPropType) => void;

type MultiplePropType = boolean;
type PropMultiple = {
    multiple: MultiplePropType;
};
declare const validateMultiple: (component: Generic.Element.Component, value?: MultiplePropType) => void;

type NamePropType = string;
type PropName = {
    name: NamePropType;
};
declare const validateName: (component: Generic.Element.Component, value?: NamePropType, options?: WatchStringOptions) => void;

type OpenPropType = boolean;
type PropOpen = {
    open: OpenPropType;
};
declare const validateOpen: (component: Generic.Element.Component, value: OpenPropType | undefined, options?: WatchBooleanOptions) => void;

type OptionsPropType = Stringified<Option<StencilUnknown>[]>;
type OptionsWithOptgroupPropType = Stringified<(Option<StencilUnknown> | Optgroup<StencilUnknown>)[]>;
type PropOptions = {
    options: OptionsPropType;
};
type PropOptionsWithOptgroup = {
    options: OptionsWithOptgroupPropType;
};
declare const validateOptions: (component: Generic.Element.Component, value: OptionsPropType | undefined, options?: WatchOptions) => void;
declare const validateOptionsWithOptgroup: (component: Generic.Element.Component, value: OptionsWithOptgroupPropType | undefined, options?: WatchOptions) => void;

declare const paginationPositionPropTypeOptions: readonly ["top", "bottom", "both"];
type PaginationPositionPropType = (typeof paginationPositionPropTypeOptions)[number];
type PropPaginationPosition = {
    paginationPosition: PaginationPositionPropType;
};
declare const validatePaginationPosition: (component: Generic.Element.Component, value?: PaginationPositionPropType) => void;

type ReadOnlyPropType = boolean;
type PropReadOnly = {
    readOnly: ReadOnlyPropType;
};
declare const validateReadOnly: (component: Generic.Element.Component, value?: ReadOnlyPropType) => void;

type RequiredPropType = boolean;
type PropRequired = {
    required: RequiredPropType;
};
declare const validateRequired: (component: Generic.Element.Component, value?: RequiredPropType) => void;

type ShowPropType = boolean;
type PropShow = {
    show: ShowPropType;
};
declare const validateShow: (component: Generic.Element.Component, value?: ShowPropType, hooks?: WatchBooleanOptions) => void;

type SuggestionsPropType = Stringified<W3CInputValue[]>;
type PropSuggestions = {
    suggestions: SuggestionsPropType;
};
declare const validateSuggestions: (component: Generic.Element.Component, value?: SuggestionsPropType) => void;

type SyncValueBySelectorPropType = string;
type PropSyncValueBySelector = {
    syncValueBySelector: SyncValueBySelectorPropType;
};

type SortEventPayload = {
    key: string;
    currentSortDirection: KoliBriSortDirection;
};
type TableCallbacksPropType = {
    [Events.onSort]?: EventValueOrEventCallback<MouseEvent, SortEventPayload>;
};
type PropTableCallbacks = {
    on: TableCallbacksPropType;
};
declare const validateTableCallbacks: (component: Generic.Element.Component, value?: TableCallbacksPropType) => void;

type TableDataPropType = Stringified<KoliBriTableDataType[]>;
type PropTableData = {
    data: TableDataPropType;
};
declare const validateTableData: (component: Generic.Element.Component, value?: TableDataPropType, setStateHooks?: SetStateHooks) => void;

type TableDataFootPropType = Stringified<KoliBriTableDataType[]>;
type PropTableDataFoot = {
    dataFoot: TableDataFootPropType;
};
declare const validateTableDataFoot: (component: Generic.Element.Component, value?: TableDataFootPropType, setStateHooks?: SetStateHooks) => void;

type TableHeaderCells = {
    horizontal?: KoliBriTableHeaderCell[][];
    vertical?: KoliBriTableHeaderCell[][];
};
type TableHeaderCellsPropType = Stringified<TableHeaderCells>;
type PropTableHeaderCells = {
    headerCells: TableHeaderCellsPropType;
};
declare const validateTableHeaderCells: (component: Generic.Element.Component, value?: TableHeaderCellsPropType) => void;

type TooltipAlignPropType = AlignPropType;
type PropTooltipAlign = {
    tooltipAlign: TooltipAlignPropType;
};
declare const validateTooltipAlign: (component: Generic.Element.Component, value?: TooltipAlignPropType) => void;

type TouchedPropType = boolean;
type PropTouched = {
    touched: TouchedPropType;
};
declare const validateTouched: (component: Generic.Element.Component, value?: TouchedPropType) => void;

declare const spinVariantPropTypeOptions: readonly ["cycle", "dot", "none"];
type SpinVariantPropType = (typeof spinVariantPropTypeOptions)[number];
type PropSpinVariant = {
    variant: SpinVariantPropType;
};
declare const validateSpinVariant: (component: Generic.Element.Component, value?: SpinVariantPropType) => void;

type RequiredProps$M = PropLabel;
type OptionalProps$M = PropTooltipAlign;
type RequiredStates$J = RequiredProps$M & OptionalProps$M;
type OptionalStates$J = NonNullable<unknown>;
type AbbrProps = Generic.Element.Members<RequiredProps$M, OptionalProps$M>;
type AbbrStates = Generic.Element.Members<RequiredStates$J, OptionalStates$J>;
type AbbrAPI = Generic.Element.ComponentApi<RequiredProps$M, OptionalProps$M, RequiredStates$J, OptionalStates$J>;

type KoliBriAccordionCallbacks = {
    [Events.onClick]?: EventValueOrEventCallback<Event, boolean>;
};
type RequiredProps$L = PropLabel;
type OptionalProps$L = {
    level: HeadingLevel;
    on: KoliBriAccordionCallbacks;
} & PropDisabled & PropOpen;
type RequiredStates$I = RequiredProps$L & PropLabel;
type OptionalStates$I = OptionalProps$L;
type AccordionProps = Generic.Element.Members<RequiredProps$L, OptionalProps$L>;
type AccordionStates = Generic.Element.Members<RequiredStates$I, OptionalStates$I>;
type AccordionAPI = Generic.Element.ComponentApi<RequiredProps$L, OptionalProps$L, RequiredStates$I, OptionalStates$I>;

declare const alertTypeOptions: readonly ["default", "info", "success", "warning", "error"];
type AlertType = (typeof alertTypeOptions)[number];
declare const alertVariantOptions: readonly ["card", "msg"];
type AlertVariant = (typeof alertVariantOptions)[number];
type KoliBriAlertEventCallbacks = {
    onClose?: EventCallback<Event>;
};
type RequiredAlertProps = NonNullable<unknown>;
type OptionalAlertProps = {
    level: HeadingLevel;
    on: KoliBriAlertEventCallbacks;
    type: AlertType;
    variant: AlertVariant;
} & PropLabel & PropAlert & PropHasCloser;
type RequiredAlertStates = RequiredAlertProps;
type OptionalAlertStates = OptionalAlertProps;
type AlertProps = Generic.Element.Members<RequiredAlertProps, OptionalAlertProps>;
type AlertStates = Generic.Element.Members<RequiredAlertStates, OptionalAlertStates>;
type AlertAPI = Generic.Element.ComponentApi<RequiredAlertProps, OptionalAlertProps, RequiredAlertStates, OptionalAlertStates>;

type RequiredAvatarProps = PropLabel;
type OptionalAvatarProps = PropImageSource;
type RequiredAvatarStates = RequiredAvatarProps;
type OptionalAvatarStates = OptionalAvatarProps;
type AvatarProps = Generic.Element.Members<RequiredAvatarProps, OptionalAvatarProps>;
type AvatarStates = Generic.Element.Members<RequiredAvatarStates, OptionalAvatarStates>;
type AvatarAPI = Generic.Element.ComponentApi<RequiredAvatarProps, OptionalAvatarProps, RequiredAvatarStates, OptionalAvatarStates>;

type RequiredButtonProps = PropLabelWithExpertSlot;
type OptionalButtonProps = {
    tabIndex: number;
    value: Stringified<StencilUnknown>;
} & PropAlternativeButtonLinkRole & PropAriaControls & PropAriaExpanded & PropAriaSelected & PropButtonCallbacks<StencilUnknown> & PropButtonType & PropButtonVariant & PropCustomClass & PropDisabled & PropHideLabel & PropIcons & PropId & PropName & PropSyncValueBySelector & PropTooltipAlign & PropAccessKey;
type RequiredButtonStates = RequiredButtonProps & PropButtonType & PropButtonVariant & {
    icons: KoliBriAllIcons;
};
type OptionalButtonStates = Omit<RequiredButtonProps & OptionalButtonProps, keyof RequiredButtonStates>;
type ButtonProps = Generic.Element.Members<RequiredButtonProps, OptionalButtonProps>;
type ButtonStates = Generic.Element.Members<RequiredButtonStates, OptionalButtonStates>;
type ButtonAPI = Generic.Element.ComponentApi<RequiredButtonProps, OptionalButtonProps, RequiredButtonStates, OptionalButtonStates>;

type RequiredProps$K = PropLabel;
type OptionalProps$K = {
    color: Stringified<PropColor>;
    smartButton: Stringified<ButtonProps>;
} & PropIcons;
type RequiredStates$H = {
    color: ColorPair;
};
type OptionalStates$H = {
    smartButton: ButtonProps;
};
type RequiredWatchers = RequiredStates$H;
type OptionalWatchers = OptionalStates$H;
type BadgeProps = Generic.Element.Members<RequiredProps$K, OptionalProps$K>;
type BadgeStates = Generic.Element.Members<RequiredStates$H, OptionalStates$H>;
type BadgeAPI = Generic.Element.Component & Generic.Element.Members<RequiredProps$K, OptionalProps$K> & Generic.Element.Watchers<RequiredWatchers, OptionalWatchers> & {
    readonly state: Generic.Element.Members<RequiredStates$H, OptionalStates$H>;
};

type RequiredProps$J = PropHref;
type OptionalProps$J = {
    tabIndex: number;
} & PropAccessKey & PropAlternativeButtonLinkRole & PropAriaCurrentValue & PropDisabled & PropDownload & PropHideLabel & PropIcons & PropLabelWithExpertSlot & PropLinkOnCallbacks & PropLinkTarget & PropTooltipAlign;
type RequiredStates$G = PropAriaCurrentValue & PropIcons & PropHref;
type OptionalStates$G = {
    ariaCurrent: string;
} & Omit<RequiredProps$J & OptionalProps$J, keyof RequiredStates$G>;
type LinkProps = Generic.Element.Members<RequiredProps$J, OptionalProps$J>;
type LinkStates = Generic.Element.Members<RequiredStates$G, OptionalStates$G>;
type LinkAPI = Generic.Element.ComponentApi<RequiredProps$J, OptionalProps$J, RequiredStates$G, OptionalStates$G>;

type BreadcrumbLinkProps = LinkProps & LabelProp;
type RequiredProps$I = {
    links: Stringified<BreadcrumbLinkProps[]>;
} & PropLabel;
type OptionalProps$I = NonNullable<unknown>;
type RequiredStates$F = {
    links: BreadcrumbLinkProps[];
} & PropLabel;
type OptionalStates$F = OptionalProps$I;
type BreadcrumbProps = Generic.Element.Members<RequiredProps$I, OptionalProps$I>;
type BreadcrumbStates = Generic.Element.Members<RequiredStates$F, OptionalStates$F>;
type BreadcrumbAPI = Generic.Element.ComponentApi<RequiredProps$I, OptionalProps$I, RequiredStates$F, OptionalStates$F>;

type RequiredProps$H = NonNullable<unknown>;
type OptionalProps$H = NonNullable<unknown>;
type RequiredStates$E = RequiredProps$H;
type OptionalStates$E = OptionalProps$H;
type ButtonGroupProps = Generic.Element.Members<RequiredProps$H, OptionalProps$H>;
type ButtonGroupStates = Generic.Element.Members<RequiredStates$E, OptionalStates$E>;
type ButtonGroupAPI = Generic.Element.ComponentApi<RequiredProps$H, OptionalProps$H, RequiredStates$E, OptionalStates$E>;

type RequiredProps$G = RequiredButtonProps;
type OptionalProps$G = Omit<OptionalButtonProps, keyof PropAlternativeButtonLinkRole>;
type ButtonLinkProps = Generic.Element.Members<RequiredProps$G, OptionalProps$G>;
type ButtonLinkStates = Generic.Element.Members<RequiredButtonStates, OptionalButtonStates>;

type KoliBriCardEventCallbacks = {
    onClose?: EventCallback<Event>;
};
type RequiredProps$F = PropLabel;
type OptionalProps$F = {
    level: HeadingLevel;
    on: KoliBriCardEventCallbacks;
} & PropHasCloser;
type RequiredStates$D = RequiredProps$F;
type OptionalStates$D = OptionalProps$F;
type CardProps = Generic.Element.Members<RequiredProps$F, OptionalProps$F>;
type CardStates = Generic.Element.Members<RequiredStates$D, OptionalStates$D>;
type CardAPI = Generic.Element.ComponentApi<RequiredProps$F, OptionalProps$F, RequiredStates$D, OptionalStates$D>;

type EventCallbacks = {
    onToggle?: EventValueOrEventCallback<Event, boolean>;
};
type RequiredProps$E = PropLabel;
type OptionalProps$E = {
    on: EventCallbacks;
} & PropDisabled & PropOpen;
type RequiredStates$C = RequiredProps$E;
type OptionalStates$C = OptionalProps$E;
type DetailsProps = Generic.Element.Members<RequiredProps$E, OptionalProps$E>;
type DetailsStates = Generic.Element.Members<RequiredStates$C, OptionalStates$C>;
type DetailsAPI = Generic.Element.ComponentApi<RequiredProps$E, OptionalProps$E, RequiredStates$C, OptionalStates$C>;

type KoliBriFormCallbacks = {
    [Events.onSubmit]?: EventCallback<Event>;
    [Events.onReset]?: EventCallback<Event>;
};
type RequiredProps$D = NonNullable<unknown>;
type OptionalProps$D = {
    on: KoliBriFormCallbacks;
    requiredText: string | boolean;
} & PropErrorList;
type RequiredStates$B = RequiredProps$D;
type OptionalStates$B = OptionalProps$D;
type FormProps = Generic.Element.Members<RequiredProps$D, OptionalProps$D>;
type FormStates = Generic.Element.Members<RequiredStates$B, OptionalStates$B>;
type FormAPI = Generic.Element.ComponentApi<RequiredProps$D, OptionalProps$D, RequiredStates$B, OptionalStates$B>;

type RequiredProps$C = PropLabelWithExpertSlot;
type OptionalProps$C = PropHeadingVariant & {
    secondaryHeadline: string;
    level: HeadingLevel;
};
type RequiredStates$A = RequiredProps$C & {
    level: HeadingLevel;
};
type OptionalStates$A = PropHeadingVariant & {
    secondaryHeadline: string;
};
type HeadingProps = Generic.Element.Members<RequiredProps$C, OptionalProps$C>;
type HeadingStates = Generic.Element.Members<RequiredStates$A, OptionalStates$A>;
type HeadingAPI = Generic.Element.ComponentApi<RequiredProps$C, OptionalProps$C, RequiredStates$A, OptionalStates$A>;

type RequiredProps$B = {
    icons: string;
} & PropLabel;
type OptionalProps$B = NonNullable<unknown>;
type RequiredStates$z = RequiredProps$B;
type OptionalStates$z = OptionalProps$B;
type IconProps = Generic.Element.Members<RequiredProps$B, OptionalProps$B>;
type IconStates = Generic.Element.Members<RequiredStates$z, OptionalStates$z>;
type IconAPI = Generic.Element.ComponentApi<RequiredProps$B, OptionalProps$B, RequiredStates$z, OptionalStates$z>;

type RequiredProps$A = {
    alt: string;
} & PropImageSource;
type OptionalProps$A = {
    loading: Loading;
    sizes: string;
    srcset: string;
};
type RequiredStates$y = RequiredProps$A & {
    loading: Loading;
};
type OptionalStates$y = {
    sizes: string;
    srcset: string;
};
type ImageProps = Generic.Element.Members<RequiredProps$A, OptionalProps$A>;
type ImageStates = Generic.Element.Members<RequiredStates$y, OptionalStates$y>;
type ImageAPI = Generic.Element.ComponentApi<RequiredProps$A, OptionalProps$A, RequiredStates$y, OptionalStates$y>;

type RequiredProps$z = NonNullable<unknown>;
type OptionalProps$z = NonNullable<unknown>;
type RequiredStates$x = RequiredProps$z;
type OptionalStates$x = OptionalProps$z;
type IndentedTextProps = Generic.Element.Members<RequiredProps$z, OptionalProps$z>;
type IndentedTextStates = Generic.Element.Members<RequiredStates$x, OptionalStates$x>;
type IndentedTextAPI = Generic.Element.ComponentApi<RequiredProps$z, OptionalProps$z, RequiredStates$x, OptionalStates$x>;

type RequiredProps$y = PropId & PropLabelWithExpertSlot;
type OptionalProps$y = {
    currentLength: number;
    error: string;
    hint: string;
    icons: KoliBriHorizontalIcons;
    maxLength: number;
    slotName: string;
    smartButton: Stringified<ButtonProps>;
} & PropAccessKey & PropAlert & PropDisabled & PropHasCounter & PropHideError & PropHideLabel & PropMsg & PropReadOnly & PropRequired & PropSuggestions & PropSyncValueBySelector & PropTooltipAlign & PropTouched;
type InputProps = Generic.Element.Members<RequiredProps$y, OptionalProps$y>;

declare const inputCheckboxVariantOptions: readonly ["button", "default", "switch"];
type InputCheckboxVariant = (typeof inputCheckboxVariantOptions)[number];
type InputCheckboxIconsProp = {
    checked: AnyIconFontClass;
    indeterminate?: AnyIconFontClass;
    unchecked?: AnyIconFontClass;
} | {
    checked?: AnyIconFontClass;
    indeterminate: AnyIconFontClass;
    unchecked?: AnyIconFontClass;
} | {
    checked?: AnyIconFontClass;
    indeterminate?: AnyIconFontClass;
    unchecked: AnyIconFontClass;
};
type InputCheckboxIconsState = {
    checked: AnyIconFontClass;
    indeterminate: AnyIconFontClass;
    unchecked: AnyIconFontClass;
};
type RequiredProps$x = PropLabelWithExpertSlot;
type OptionalProps$x = {
    accessKey: string;
    alert: boolean;
    error: string;
    hint: string;
    icons: Stringified<InputCheckboxIconsProp>;
    on: InputTypeOnDefault;
    tabIndex: number;
    value: Stringified<StencilUnknown>;
    variant: InputCheckboxVariant;
} & PropChecked & PropDisabled & PropHideError & PropHideLabel & PropIndeterminate & PropMsg & PropName & PropRequired & PropSyncValueBySelector & PropTouched;
type RequiredStates$w = {
    icons: InputCheckboxIconsState;
    id: string;
    value: StencilUnknown;
    variant: InputCheckboxVariant;
} & PropChecked & PropHideError & PropIndeterminate & PropLabelWithExpertSlot;
type OptionalStates$w = {
    accessKey: string;
    alert: boolean;
    hint: string;
    on: InputTypeOnDefault;
    tabIndex: number;
} & PropDisabled & PropHideLabel & PropMsg & PropName & PropRequired & PropTouched;
type InputCheckboxProps = Generic.Element.Members<RequiredProps$x, OptionalProps$x>;
type InputCheckboxStates = Generic.Element.Members<RequiredStates$w, OptionalStates$w>;
type InputCheckboxWatches = Generic.Element.Watchers<RequiredProps$x, OptionalProps$x>;
type InputCheckboxAPI = Generic.Element.ComponentApi<RequiredProps$x, OptionalProps$x, RequiredStates$w, OptionalStates$w>;

type RequiredProps$w = PropLabelWithExpertSlot;
type OptionalProps$w = {
    accessKey: string;
    alert: boolean;
    autoComplete: InputTypeOnOff;
    error: string;
    hint: string;
    icons: Stringified<KoliBriHorizontalIcons>;
    on: InputTypeOnDefault;
    smartButton: Stringified<ButtonProps>;
    tabIndex: number;
    value: string;
} & PropDisabled & PropHideError & PropHideLabel & PropMsg & PropName & PropSuggestions & PropSyncValueBySelector & PropTouched;
type RequiredStates$v = {
    autoComplete: InputTypeOnOff;
    id: string;
    suggestions: W3CInputValue[];
} & PropHideError & PropLabelWithExpertSlot;
type OptionalStates$v = {
    accessKey: string;
    alert: boolean;
    hint: string;
    icons: KoliBriHorizontalIcons;
    on: InputTypeOnDefault;
    smartButton: ButtonProps;
    tabIndex: number;
    value: string;
} & PropDisabled & PropHideLabel & PropMsg & PropName & PropTouched;
type InputColorProps = Generic.Element.Members<RequiredProps$w, OptionalProps$w>;
type InputColorStates = Generic.Element.Members<RequiredStates$v, OptionalStates$v>;
type InputColorWatches = Generic.Element.Watchers<RequiredProps$w, OptionalProps$w>;
type InputColorAPI = Generic.Element.ComponentApi<RequiredProps$w, OptionalProps$w, RequiredStates$v, OptionalStates$v>;

type RequiredProps$v = PropLabelWithExpertSlot;
type OptionalProps$v = {
    error: string;
    type: InputDateType;
} & OptionalInputProps<Iso8601 | Date> & PropHideError & PropSuggestions & PropMsg;
type RequiredStates$u = {
    autoComplete: InputTypeOnOff;
    hasValue: boolean;
    suggestions: W3CInputValue[];
    type: InputDateType;
} & PropLabelWithExpertSlot & PropHideError & PropId;
type OptionalStates$u = {
    accessKey: string;
    alert: boolean;
    hint: string;
    icons: KoliBriHorizontalIcons;
    max: Iso8601;
    min: Iso8601;
    on: InputTypeOnDefault;
    placeholder: string;
    smartButton: ButtonProps;
    step: number;
    tabIndex: number;
    value: Iso8601 | null;
} & PropSyncValueBySelector & PropDisabled & PropHideLabel & PropMsg & PropName & PropReadOnly & PropRequired & PropTouched;
type InputDateProps = Generic.Element.Members<RequiredProps$v, OptionalProps$v>;
type InputDateStates = Generic.Element.Members<RequiredStates$u, OptionalStates$u>;
type InputDateWatches = Generic.Element.Watchers<RequiredProps$v, OptionalProps$v>;
type InputDateAPI = Generic.Element.ComponentApi<RequiredProps$v, OptionalProps$v, RequiredStates$u, OptionalStates$u>;

type RequiredProps$u = PropLabelWithExpertSlot;
type OptionalProps$u = {
    accessKey: string;
    alert: boolean;
    autoComplete: InputTypeOnOff;
    error: string;
    hint: string;
    icons: Stringified<KoliBriHorizontalIcons>;
    maxLength: number;
    on: InputTypeOnDefault;
    pattern: string;
    placeholder: string;
    smartButton: Stringified<ButtonProps>;
    tabIndex: number;
    value: string;
} & PropDisabled & PropHasCounter & PropHideError & PropHideLabel & PropMsg & PropMultiple & PropName & PropReadOnly & PropRequired & PropSuggestions & PropSyncValueBySelector & PropTouched;
type RequiredStates$t = {
    autoComplete: InputTypeOnOff;
    hasValue: boolean;
    suggestions: W3CInputValue[];
} & PropId & PropHideError & PropLabelWithExpertSlot;
type OptionalStates$t = {
    accessKey: string;
    alert: boolean;
    currentLength: number;
    hint: string;
    icons: KoliBriHorizontalIcons;
    maxLength: number;
    on: InputTypeOnDefault;
    pattern: string;
    placeholder: string;
    smartButton: ButtonProps;
    tabIndex: number;
    value: string;
} & PropDisabled & PropHasCounter & PropHideLabel & PropMsg & PropMultiple & PropName & PropReadOnly & PropRequired & PropTouched;
type InputEmailProps = Generic.Element.Members<RequiredProps$u, OptionalProps$u>;
type InputEmailStates = Generic.Element.Members<RequiredStates$t, OptionalStates$t>;
type InputEmailWatches = Generic.Element.Watchers<RequiredProps$u, OptionalProps$u>;
type InputEmailAPI = Generic.Element.ComponentApi<RequiredProps$u, OptionalProps$u, RequiredStates$t, OptionalStates$t>;

type RequiredProps$t = PropLabelWithExpertSlot;
type OptionalProps$t = {
    accept: string;
    alert: boolean;
    accessKey: string;
    error: string;
    hint: string;
    icons: Stringified<KoliBriHorizontalIcons>;
    on: InputTypeOnDefault;
    smartButton: Stringified<ButtonProps>;
    tabIndex: number;
    value: string;
} & PropDisabled & PropHideError & PropHideLabel & PropMsg & PropMultiple & PropName & PropRequired & PropSyncValueBySelector & PropTouched;
type RequiredStates$s = PropId & PropLabelWithExpertSlot & PropHideError;
type OptionalStates$s = {
    accept: string;
    alert: boolean;
    accessKey: string;
    hint: string;
    icons: KoliBriHorizontalIcons;
    on: InputTypeOnDefault;
    smartButton: ButtonProps;
    tabIndex: number;
    value: string;
} & PropDisabled & PropHideLabel & PropMsg & PropMultiple & PropName & PropRequired & PropTouched;
type InputFileProps = Generic.Element.Members<RequiredProps$t, OptionalProps$t>;
type InputFileStates = Generic.Element.Members<RequiredStates$s, OptionalStates$s>;
type InputFileWatches = Generic.Element.Watchers<RequiredProps$t, OptionalProps$t>;
type InputFileAPI = Generic.Element.ComponentApi<RequiredProps$t, OptionalProps$t, RequiredStates$s, OptionalStates$s>;

type RequiredProps$s = PropLabelWithExpertSlot;
type OptionalProps$s = {
    error: string;
    placeholder: string;
} & OptionalInputProps<number | Iso8601> & PropHideError & PropMsg & PropSuggestions;
type RequiredStates$r = {
    autoComplete: InputTypeOnOff;
    hasValue: boolean;
    suggestions: W3CInputValue[];
} & PropId & PropHideError & PropLabelWithExpertSlot;
type OptionalStates$r = {
    accessKey: string;
    alert: boolean;
    hint: string;
    icons: KoliBriHorizontalIcons;
    max: string;
    min: string;
    on: InputTypeOnDefault;
    placeholder: string;
    smartButton: ButtonProps;
    step: number;
    tabIndex: number;
    value: string;
} & PropDisabled & PropHideLabel & PropMsg & PropName & PropReadOnly & PropRequired & PropSyncValueBySelector & PropTouched;
type InputNumberProps = Generic.Element.Members<RequiredProps$s, OptionalProps$s>;
type InputNumberStates = Generic.Element.Members<RequiredStates$r, OptionalStates$r>;
type InputNumberWatches = Generic.Element.Watchers<RequiredProps$s, OptionalProps$s>;
type InputNumberAPI = Generic.Element.ComponentApi<RequiredProps$s, OptionalProps$s, RequiredStates$r, OptionalStates$r>;

type RequiredProps$r = PropLabelWithExpertSlot;
type OptionalProps$r = {
    accessKey: string;
    alert: boolean;
    autoComplete: InputTypeOnOff;
    error: string;
    hint: string;
    icons: Stringified<KoliBriHorizontalIcons>;
    maxLength: number;
    on: InputTypeOnDefault;
    pattern: string;
    placeholder: string;
    smartButton: Stringified<ButtonProps>;
    tabIndex: number;
    value: string;
} & PropDisabled & PropHasCounter & PropHideError & PropHideLabel & PropMsg & PropName & PropReadOnly & PropRequired & PropSyncValueBySelector & PropTouched;
type RequiredStates$q = {
    autoComplete: InputTypeOnOff;
    hasValue: boolean;
} & PropId & PropHideError & PropLabelWithExpertSlot;
type OptionalStates$q = {
    accessKey: string;
    alert: boolean;
    currentLength: number;
    hint: string;
    icons: KoliBriHorizontalIcons;
    maxLength: number;
    on: InputTypeOnDefault;
    pattern: string;
    placeholder: string;
    smartButton: ButtonProps;
    tabIndex: number;
    value: string | null;
} & PropDisabled & PropHasCounter & PropHideLabel & PropMsg & PropName & PropReadOnly & PropRequired & PropTouched;
type InputPasswordProps = Generic.Element.Members<RequiredProps$r, OptionalProps$r>;
type InputPasswordStates = Generic.Element.Members<RequiredStates$q, OptionalStates$q>;
type InputPasswordWatches = Generic.Element.Watchers<RequiredProps$r, OptionalProps$r>;
type InputPasswordAPI = Generic.Element.ComponentApi<RequiredProps$r, OptionalProps$r, RequiredStates$q, OptionalStates$q>;

type RequiredProps$q = PropLabelWithExpertSlot;
type OptionalProps$q = {
    accessKey: string;
    alert: boolean;
    error: string;
    hint: string;
    on: InputTypeOnDefault;
    orientation: Orientation;
    tabIndex: number;
    value: StencilUnknown;
} & PropDisabled & PropHideError & PropHideLabel & PropMsg & PropName & PropOptions & PropRequired & PropSyncValueBySelector & PropTouched & PropTooltipAlign;
type RequiredStates$p = {
    options: Option<StencilUnknown>[];
    orientation: Orientation;
} & PropId & PropHideError & PropLabelWithExpertSlot;
type OptionalStates$p = {
    accessKey: string;
    alert: boolean;
    hint: string;
    on: InputTypeOnDefault;
    tabIndex: number;
    value: StencilUnknown;
} & PropDisabled & PropHideLabel & PropMsg & PropName & PropRequired & PropTouched;
type InputRadioProps = Generic.Element.Members<RequiredProps$q, OptionalProps$q>;
type InputRadioStates = Generic.Element.Members<RequiredStates$p, OptionalStates$p>;
type InputRadioWatches = Generic.Element.Watchers<RequiredProps$q, OptionalProps$q>;
type InputRadioAPI = Generic.Element.ComponentApi<RequiredProps$q, OptionalProps$q, RequiredStates$p, OptionalStates$p>;

type RequiredProps$p = PropLabelWithExpertSlot;
type OptionalProps$p = {
    accessKey: string;
    alert: boolean;
    autoComplete: InputTypeOnOff;
    error: string;
    hint: string;
    icons: Stringified<KoliBriHorizontalIcons>;
    max: number;
    min: number;
    on: InputTypeOnDefault;
    step: number;
    tabIndex: number;
    value: number;
} & PropDisabled & PropHideError & PropHideLabel & PropMsg & PropName & PropSuggestions & PropSyncValueBySelector & PropTouched;
type RequiredStates$o = {
    autoComplete: InputTypeOnOff;
    suggestions: W3CInputValue[];
} & PropId & PropHideError & PropLabelWithExpertSlot;
type OptionalStates$o = {
    accessKey: string;
    alert: boolean;
    hint: string;
    icons: KoliBriHorizontalIcons;
    max: number;
    min: number;
    on: InputTypeOnDefault;
    step: number;
    tabIndex: number;
    value: number;
} & PropDisabled & PropHideLabel & PropMsg & PropName & PropTouched;
type InputRangeProps = Generic.Element.Members<RequiredProps$p, OptionalProps$p>;
type InputRangeStates = Generic.Element.Members<RequiredStates$o, OptionalStates$o>;
type InputRangeWatches = Generic.Element.Watchers<RequiredProps$p, OptionalProps$p>;
type InputRangeAPI = Generic.Element.ComponentApi<RequiredProps$p, OptionalProps$p, RequiredStates$o, OptionalStates$o>;

type RequiredProps$o = PropLabelWithExpertSlot;
type OptionalProps$o = {
    accessKey: string;
    alert: boolean;
    autoComplete: InputTypeOnOff;
    error: string;
    hint: string;
    icons: Stringified<KoliBriHorizontalIcons>;
    maxLength: number;
    on: InputTypeOnDefault;
    pattern: string;
    placeholder: string;
    smartButton: Stringified<ButtonProps>;
    tabIndex: number;
    type: InputTextType;
    value: string;
} & PropDisabled & PropHasCounter & PropHideError & PropHideLabel & PropId & PropMsg & PropName & PropReadOnly & PropRequired & PropSuggestions & PropSyncValueBySelector & PropTouched;
type RequiredStates$n = {
    autoComplete: InputTypeOnOff;
    hasValue: boolean;
    suggestions: W3CInputValue[];
    type: InputTextType;
} & PropId & PropHideError & PropLabelWithExpertSlot;
type OptionalStates$n = {
    accessKey: string;
    alert: boolean;
    currentLength: number;
    hint: string;
    icons: KoliBriHorizontalIcons;
    maxLength: number;
    on: InputTypeOnDefault;
    pattern: string;
    placeholder: string;
    smartButton: ButtonProps;
    tabIndex: number;
    value: string;
} & PropDisabled & PropHasCounter & PropHideLabel & PropMsg & PropName & PropReadOnly & PropRequired & PropTouched;
type InputTextProps = Generic.Element.Members<RequiredProps$o, OptionalProps$o>;
type InputTextStates = Generic.Element.Members<RequiredStates$n, OptionalStates$n>;
type InputTextWatches = Generic.Element.Watchers<RequiredProps$o, OptionalProps$o>;
type InputTextAPI = Generic.Element.ComponentApi<RequiredProps$o, OptionalProps$o, RequiredStates$n, OptionalStates$n>;

type RequiredProps$n = NonNullable<unknown>;
type OptionalProps$n = {
    color: Stringified<PropColor>;
    labeled: boolean;
};
type RequiredStates$m = {
    color: {
        red: number;
        green: number;
        blue: number;
    };
    labeled: boolean;
};
type OptionalStates$m = NonNullable<unknown>;
type KolibriProps = Generic.Element.Members<RequiredProps$n, OptionalProps$n>;
type KolibriStates = Generic.Element.Members<RequiredStates$m, OptionalStates$m>;
type KolibriAPI = Generic.Element.ComponentApi<RequiredProps$n, OptionalProps$n, RequiredStates$m, OptionalStates$m>;

type RequiredProps$m = RequiredProps$J;
type OptionalProps$m = Omit<OptionalProps$J, keyof PropAlternativeButtonLinkRole>;
type LinkButtonProps = Generic.Element.Members<RequiredProps$m, OptionalProps$m>;

type ListStyleType = 'disc' | 'circle' | 'square' | 'none' | 'decimal' | 'decimal-leading-zero' | 'lower-alpha' | 'lower-greek' | 'lower-latin' | 'lower-roman' | 'upper-alpha' | 'upper-latin' | 'upper-roman';
type RequiredProps$l = {
    links: Stringified<LinkProps[]>;
};
type OptionalProps$l = {
    listStyleType: ListStyleType;
    orientation: Orientation;
} & PropLabel;
type RequiredStates$l = {
    links: LinkProps[];
    listStyleType: ListStyleType;
    orientation: Orientation;
};
type OptionalStates$l = NonNullable<unknown> & PropLabel;
type LinkGroupProps = Generic.Element.Members<RequiredProps$l, OptionalProps$l>;
type LinkGroupStates = Generic.Element.Members<RequiredStates$l, OptionalStates$l>;
type LinkGroupAPI = Generic.Element.ComponentApi<RequiredProps$l, OptionalProps$l, RequiredStates$l, OptionalStates$l>;

type RequiredProps$k = PropLabel;
type OptionalProps$k = {
    activeElement: HTMLElement | null;
    on: KoliBriModalEventCallbacks;
    width: string;
};
type RequiredStates$k = {
    activeElement: HTMLElement | null;
    width: string;
} & PropLabel;
type OptionalStates$k = {
    on: KoliBriModalEventCallbacks;
};
type ModalProps = Generic.Element.Members<RequiredProps$k, OptionalProps$k>;
type ModalStates = Generic.Element.Members<RequiredStates$k, OptionalStates$k>;
type ModalAPI = Generic.Element.ComponentApi<RequiredProps$k, OptionalProps$k, RequiredStates$k, OptionalStates$k>;

type RequiredProps$j = {
    links: Stringified<ButtonOrLinkOrTextWithChildrenProps[]>;
} & PropLabel;
type OptionalProps$j = {
    orientation: Orientation;
} & PropCollapsible & PropHasCompactButton & PropHideLabel & PropHasIconsWhenExpanded;
type RequiredStates$j = {
    links: ButtonOrLinkOrTextWithChildrenProps[];
    orientation: Orientation;
    expandedChildren: ButtonOrLinkOrTextWithChildrenProps[][];
} & PropCollapsible & PropHasCompactButton & PropLabel & PropHideLabel & PropHasIconsWhenExpanded;
type OptionalStates$j = NonNullable<unknown>;
type NavProps = Generic.Element.Members<RequiredProps$j, OptionalProps$j>;
type NavStates = Generic.Element.Members<RequiredStates$j, OptionalStates$j>;
type NavAPI = Generic.Element.ComponentApi<RequiredProps$j, OptionalProps$j, RequiredStates$j, OptionalStates$j>;

type KoliBriPaginationButtonCallbacks = {
    [Events.onClick]?: EventValueOrEventCallback<Event, number>;
    onChangePage?: EventValueOrEventCallback<Event, number>;
    onChangePageSize?: EventValueOrEventCallback<Event, number>;
};
type PaginationHasButton = {
    first: boolean;
    last: boolean;
    next: boolean;
    previous: boolean;
};
type RequiredProps$i = {
    on: KoliBriPaginationButtonCallbacks;
    page: number;
} & PropMax;
type OptionalProps$i = {
    boundaryCount: number;
    hasButtons: boolean | Stringified<PaginationHasButton>;
    pageSize: number;
    pageSizeOptions: Stringified<number[]>;
    siblingCount: number;
} & PropCustomClass & PropLabel & PropTooltipAlign;
type KoliBriPaginationProps = RequiredProps$i & OptionalProps$i;
type RequiredStates$i = {
    boundaryCount: number;
    hasButtons: PaginationHasButton;
    page: number;
    pageSize: number;
    pageSizeOptions: Option<number>[];
    on: KoliBriPaginationButtonCallbacks;
    siblingCount: number;
} & PropLabel & PropMax;
type OptionalStates$i = PropCustomClass & PropTooltipAlign;
type PaginationProps = Generic.Element.Members<RequiredProps$i, OptionalProps$i>;
type PaginationStates = Generic.Element.Members<RequiredStates$i, OptionalStates$i>;
type PaginationAPI = Generic.Element.ComponentApi<RequiredProps$i, OptionalProps$i, RequiredStates$i, OptionalStates$i>;

type RequiredProps$h = NonNullable<unknown>;
type OptionalProps$h = PropAlign & PropShow;
type RequiredStates$h = PropAlign & PropShow & {
    visible: boolean;
};
type OptionalStates$h = NonNullable<unknown>;
type PopoverProps = Generic.Element.Members<RequiredProps$h, OptionalProps$h>;
type PopoverStates = Generic.Element.Members<RequiredStates$h, OptionalStates$h>;
type PopoverAPI = Generic.Element.ComponentApi<RequiredProps$h, OptionalProps$h, RequiredStates$h, OptionalStates$h>;

type RequiredProps$g = {
    max: number;
    value: number;
};
type OptionalProps$g = {
    unit: string;
    variant: KoliBriProgressVariantType;
} & PropLabel;
type RequiredStates$g = RequiredProps$g & {
    liveValue: number;
};
type OptionalStates$g = {
    unit: string;
    variant: KoliBriProgressVariantType;
} & PropLabel;
type ProgressProps = Generic.Element.Members<RequiredProps$g, OptionalProps$g>;
type ProgressStates = Generic.Element.Members<RequiredStates$g, OptionalStates$g>;
type ProgressAPI = Generic.Element.ComponentApi<RequiredProps$g, OptionalProps$g, RequiredStates$g, OptionalStates$g>;

declare const koliBriQuoteVariantOptions: readonly ["block", "inline"];
type KoliBriQuoteVariant = (typeof koliBriQuoteVariantOptions)[number];
type RequiredProps$f = {
    quote: string;
} & PropHref;
type OptionalProps$f = {
    variant: KoliBriQuoteVariant;
} & PropLabel;
type RequiredStates$f = {
    quote: string;
    variant: KoliBriQuoteVariant;
} & PropHref;
type OptionalStates$f = PropLabel;
type QuoteProps = Generic.Element.Members<RequiredProps$f, OptionalProps$f>;
type QuoteStates = Generic.Element.Members<RequiredStates$f, OptionalStates$f>;
type QuoteAPI = Generic.Element.ComponentApi<RequiredProps$f, OptionalProps$f, RequiredStates$f, OptionalStates$f>;

type RequiredProps$e = NonNullable<unknown>;
type OptionalProps$e = {
    accessKey: string;
    alert: boolean;
    error: string;
    hint: string;
    icons: Stringified<KoliBriHorizontalIcons>;
    on: InputTypeOnDefault;
    tabIndex: number;
    value: Stringified<W3CInputValue[]>;
} & PropDisabled & PropHideError & PropHideLabel & PropLabelWithExpertSlot & PropMsg & PropMultiple & PropName & PropOptionsWithOptgroup & PropRequired & PropRows & PropSyncValueBySelector & PropTouched;
type RequiredStates$e = {
    hasValue: boolean;
    options: SelectOption<W3CInputValue>[];
    value: W3CInputValue[];
} & PropId & PropHideError & PropMultiple & PropLabelWithExpertSlot;
type OptionalStates$e = {
    accessKey: string;
    alert: boolean;
    error: string;
    hint: string;
    icons: KoliBriHorizontalIcons;
    on: InputTypeOnDefault;
    tabIndex: number;
} & PropDisabled & PropHideLabel & PropId & PropName & PropRequired & PropRows & PropMsg & PropTouched;
type SelectProps = Generic.Element.Members<RequiredProps$e, OptionalProps$e>;
type SelectStates = Generic.Element.Members<RequiredStates$e, OptionalStates$e>;
type SelectWatches = Generic.Element.Watchers<RequiredProps$e, OptionalProps$e>;
type SelectAPI = Generic.Element.ComponentApi<RequiredProps$e, OptionalProps$e, RequiredStates$e, OptionalStates$e>;

type RequiredProps$d = {
    links: Stringified<LinkProps[]>;
} & PropLabel;
type OptionalProps$d = NonNullable<unknown>;
type RequiredStates$d = {
    links: LinkProps[];
} & PropLabel;
type OptionalStates$d = OptionalProps$d;
type SkipNavProps = Generic.Element.Members<RequiredProps$d, OptionalProps$d>;
type SkipNavStates = Generic.Element.Members<RequiredStates$d, OptionalStates$d>;
type SkipNavAPI = Generic.Element.ComponentApi<RequiredProps$d, OptionalProps$d, RequiredStates$d, OptionalStates$d>;

type RequiredProps$c = PropLabelWithExpertSlot;
type OptionalProps$c = {
    allowMarkdown: boolean;
    icons: Stringified<KoliBriIconsProp>;
} & PropHideLabel & PropAccessKey;
type RequiredStates$c = {
    allowMarkdown: boolean;
    icons: {
        top?: KoliBriCustomIcon;
        right?: KoliBriCustomIcon;
        bottom?: KoliBriCustomIcon;
        left?: KoliBriCustomIcon;
    };
} & PropLabelWithExpertSlot;
type OptionalStates$c = PropHideLabel & PropAccessKey;
type SpanProps = Generic.Element.Members<RequiredProps$c, OptionalProps$c>;
type SpanStates = Generic.Element.Members<RequiredStates$c, OptionalStates$c>;
type SpanAPI = Generic.Element.ComponentApi<RequiredProps$c, OptionalProps$c, RequiredStates$c, OptionalStates$c>;

type RequiredProps$b = NonNullable<unknown>;
type OptionalProps$b = PropSpinVariant & PropShow;
type RequiredStates$b = PropSpinVariant;
type OptionalStates$b = PropShow;
type SpinProps = Generic.Element.Members<RequiredProps$b, OptionalProps$b>;
type SpinStates = Generic.Element.Members<RequiredStates$b, OptionalStates$b>;
type SpinAPI = Generic.Element.ComponentApi<RequiredProps$b, OptionalProps$b, RequiredStates$b, OptionalStates$b>;

type RequiredProps$a = PropLabel;
type OptionalProps$a = {
    on?: ButtonCallbacksPropType<StencilUnknown>;
} & PropAlternativeButtonLinkRole & PropIcons & PropTooltipAlign & PropButtonVariant;
type RequiredStates$a = PropShow;
type OptionalStates$a = NonNullable<unknown>;
type SplitButtonProps = Generic.Element.Members<RequiredProps$a, OptionalProps$a>;
type SplitButtonStates = Generic.Element.Members<RequiredStates$a, OptionalStates$a>;
type SplitButtonAPI = Generic.Element.ComponentApi<RequiredProps$a, OptionalProps$a, RequiredStates$a, OptionalStates$a>;

type RequiredProps$9 = {
    symbol: string;
} & PropLabel;
type OptionalProps$9 = NonNullable<unknown>;
type RequiredStates$9 = RequiredProps$9;
type OptionalStates$9 = NonNullable<unknown>;
type SymbolProps = Generic.Element.Members<RequiredProps$9, OptionalProps$9>;
type SymbolStates = Generic.Element.Members<RequiredStates$9, OptionalStates$9>;
type SymbolAPI = Generic.Element.ComponentApi<RequiredProps$9, OptionalProps$9, RequiredStates$9, OptionalStates$9>;

type KoliBriTableSelectedHead = {
    key: string;
    label: string;
    sortDirection: KoliBriSortDirection;
};
type KoliBriTableSort = <T>(data: T[]) => T[];
type KoliBriSortFunction = (data: KoliBriTableDataType[]) => KoliBriTableDataType[];
type KoliBriDataCompareFn = (a: KoliBriTableDataType, b: KoliBriTableDataType) => number;
type KoliBriTableHeaderCellWithLogic = KoliBriTableHeaderCell & {
    compareFn?: KoliBriDataCompareFn;
    sort?: KoliBriTableSort;
    sortDirection?: KoliBriSortDirection;
};
type KoliBriTableHeaders = {
    horizontal?: KoliBriTableHeaderCellWithLogic[][];
    vertical?: KoliBriTableHeaderCellWithLogic[][];
};
type KoliBriTableHeaderCellAndData = KoliBriTableHeaderCellWithLogic & {
    data: KoliBriTableDataType;
};
type KoliBriTablePaginationProps = Generic.Element.Members<{
    page: number;
}, KoliBriPaginationProps>;
type KoliBriTablePaginationStates = Generic.Element.Members<{
    page: number;
    max: number;
}, KoliBriPaginationProps>;
type RequiredProps$8 = {
    headers: Stringified<KoliBriTableHeaders>;
} & PropTableData & PropLabel;
type OptionalProps$8 = {
    allowMultiSort: boolean;
    minWidth: string;
    pagination: boolean | Stringified<KoliBriTablePaginationProps>;
} & PropTableDataFoot & PropPaginationPosition;
type RequiredStates$8 = {
    allowMultiSort: boolean;
    data: KoliBriTableDataType[];
    dataFoot: KoliBriTableDataType[];
    headers: KoliBriTableHeaders;
    pagination: KoliBriTablePaginationStates;
    sortedData: KoliBriTableDataType[];
} & PropLabel & PropPaginationPosition;
type OptionalStates$8 = {
    minWidth: string;
    sortDirection: KoliBriSortDirection;
};
type TableProps = Generic.Element.Members<RequiredProps$8, OptionalProps$8>;
type TableStates = Generic.Element.Members<RequiredStates$8, OptionalStates$8>;
type TableAPI = Generic.Element.ComponentApi<RequiredProps$8, OptionalProps$8, RequiredStates$8, OptionalStates$8>;

type RequiredProps$7 = PropLabel & PropTableData & PropTableHeaderCells;
type OptionalProps$7 = {
    minWidth: string;
} & PropTableDataFoot & PropTableCallbacks;
type RequiredStates$7 = {
    headerCells: TableHeaderCells;
    data: KoliBriTableDataType[];
} & PropLabel;
type OptionalStates$7 = {
    minWidth: string;
    dataFoot: KoliBriTableDataType[];
} & PropTableCallbacks;
type TableStatelessProps = Generic.Element.Members<RequiredProps$7, OptionalProps$7>;
type TableStatelessStates = Generic.Element.Members<RequiredStates$7, OptionalStates$7>;
type TableStatelessAPI = Generic.Element.ComponentApi<RequiredProps$7, OptionalProps$7, RequiredStates$7, OptionalStates$7>;

type KoliBriTabsCallbacks = {
    onCreate?: EventCallback<Event> | {
        label: string;
        callback: EventCallback<Event>;
    };
} & {
    [Events.onSelect]?: EventValueOrEventCallback<CustomEvent | KeyboardEvent | MouseEvent | PointerEvent, number>;
};
type RequiredTabButtonProps = PropLabel;
type OptionalTabButtonProps = {
    icons: Stringified<KoliBriIconsProp>;
} & PropDisabled & PropHideLabel & PropTooltipAlign;
type TabButtonProps = Generic.Element.Members<RequiredTabButtonProps, OptionalTabButtonProps>;
type RequiredProps$6 = {
    tabs: Stringified<TabButtonProps[]>;
} & PropLabel;
type OptionalProps$6 = {
    on: KoliBriTabsCallbacks;
    selected: number;
} & PropAlign;
type RequiredStates$6 = {
    selected: number;
    tabs: TabButtonProps[];
} & PropLabel & PropAlign;
type OptionalStates$6 = {
    on: KoliBriTabsCallbacks;
};
type TabsProps = Generic.Element.Members<RequiredProps$6, OptionalProps$6>;
type TabsStates = Generic.Element.Members<RequiredStates$6, OptionalStates$6>;
type TabsAPI = Generic.Element.ComponentApi<RequiredProps$6, OptionalProps$6, RequiredStates$6, OptionalStates$6>;

declare const cssResizeOptions: readonly ["both", "horizontal", "vertical", "none"];
type CSSResize = (typeof cssResizeOptions)[number];
type RequiredProps$5 = NonNullable<unknown>;
type OptionalProps$5 = {
    accessKey: string;
    alert: boolean;
    error: string;
    hint: string;
    maxLength: number;
    on: InputTypeOnDefault;
    placeholder: string;
    resize: CSSResize;
    tabIndex: number;
    value: string;
} & PropAdjustHeight & PropDisabled & PropHasCounter & PropHideError & PropHideLabel & PropLabelWithExpertSlot & PropMsg & PropName & PropReadOnly & PropRequired & PropRows & PropSyncValueBySelector & PropTouched;
type RequiredStates$5 = {
    adjustHeight: boolean;
    currentLength: number;
    hasValue: boolean;
    resize: CSSResize;
} & PropId & PropAdjustHeight & PropHideError & PropLabelWithExpertSlot;
type OptionalStates$5 = {
    accessKey: string;
    alert: boolean;
    error: string;
    hint: string;
    maxLength: number;
    on: InputTypeOnDefault;
    placeholder: string;
    tabIndex: number;
    value: string;
} & PropDisabled & PropHasCounter & PropHideLabel & PropMsg & PropName & PropReadOnly & PropRequired & PropRows & PropTouched;
type TextareaProps = Generic.Element.Members<RequiredProps$5, OptionalProps$5>;
type TextareaStates = Generic.Element.Members<RequiredStates$5, OptionalStates$5>;
type TextareaWatches = Generic.Element.Watchers<RequiredProps$5, OptionalProps$5>;
type TextareaAPI = Generic.Element.ComponentApi<RequiredProps$5, OptionalProps$5, RequiredStates$5, OptionalStates$5>;

declare const toastStatusOptions: readonly ["adding", "settled", "removing"];
type ToastStatus = (typeof toastStatusOptions)[number];
type ToastRenderFunction = (nodeRef: HTMLElement, options: {
    close: () => void;
}) => void;
type Toast = {
    description?: string;
    render?: ToastRenderFunction;
    label: LabelPropType;
    type: AlertType;
    alertVariant?: AlertVariant;
};
type ToastState = {
    toast: Toast;
    status: ToastStatus;
    id: string;
};
type ToasterOptions = {
    defaultAlertVariant: AlertVariant;
};
type RequiredProps$4 = NonNullable<unknown>;
type OptionalProps$4 = NonNullable<unknown>;
type RequiredStates$4 = RequiredProps$4 & {
    toastStates: ToastState[];
};
type OptionalStates$4 = OptionalProps$4;
type ToasterProps = Generic.Element.Members<RequiredProps$4, OptionalProps$4>;
type ToasterStates = Generic.Element.Members<RequiredStates$4, OptionalStates$4>;
type ToasterAPI = Generic.Element.ComponentApi<RequiredProps$4, OptionalProps$4, RequiredStates$4, OptionalStates$4>;

type RequiredProps$3 = PropLabel;
type OptionalProps$3 = PropAccessKey & PropAlign & PropId;
type RequiredStates$3 = PropLabel & PropAlign;
type OptionalStates$3 = PropAccessKey & PropId;
type TooltipProps = Generic.Element.Members<RequiredProps$3, OptionalProps$3>;
type TooltipStates = Generic.Element.Members<RequiredStates$3, OptionalStates$3>;
type TooltipAPI = Generic.Element.ComponentApi<RequiredProps$3, OptionalProps$3, RequiredStates$3, OptionalStates$3>;

type RequiredProps$2 = PropLabel;
type OptionalProps$2 = unknown;
type RequiredStates$2 = RequiredProps$2;
type OptionalStates$2 = OptionalProps$2;
type TreeProps = Generic.Element.Members<RequiredProps$2, OptionalProps$2>;
type TreeStates = Generic.Element.Members<RequiredStates$2, OptionalStates$2>;
type TreeAPI = Generic.Element.ComponentApi<RequiredProps$2, OptionalProps$2, RequiredStates$2, OptionalStates$2>;

type RequiredProps$1 = PropLabel & PropHref;
type OptionalProps$1 = PropOpen & PropActive;
type RequiredStates$1 = RequiredProps$1 & {
    hasChildren: boolean;
};
type OptionalStates$1 = OptionalProps$1;
type TreeItemProps = Generic.Element.Members<RequiredProps$1, OptionalProps$1>;
type TreeItemStates = Generic.Element.Members<RequiredStates$1, OptionalStates$1>;
type TreeItemAPI = Generic.Element.ComponentApi<RequiredProps$1, OptionalProps$1, RequiredStates$1, OptionalStates$1>;

type RequiredProps = PropLabel;
type OptionalProps = NonNullable<unknown>;
type RequiredStates = PropLabel;
type OptionalStates = NonNullable<unknown>;
type VersionProps = Generic.Element.Members<RequiredProps, OptionalProps>;
type VersionStates = Generic.Element.Members<RequiredStates, OptionalStates>;
type VersionAPI = Generic.Element.ComponentApi<RequiredProps, OptionalProps, RequiredStates, OptionalStates>;

declare const validateAlignment: (component: Generic.Element.Component, propName: string, value?: AlignPropType) => void;

declare const isObject: (value: unknown) => boolean;
declare const isString: (value: unknown, minLength?: number) => boolean;
declare const isStyle: (style?: Record<string, string>) => boolean;
declare const STATE_CHANGE_EVENT: Event;

declare const validateInputSelectOptions: <T>(option: SelectOption<T>) => boolean;

declare const validateTabIndex: (component: Generic.Element.Component, value?: number) => void;

declare const KoliBri: Theme<"kol", "error" | "warning" | "info" | "success" | "message" | "close" | "form-description" | "of" | "characters" | "new" | "no-entries" | "change-order" | "action-running" | "action-done" | "page-first" | "page-back" | "page-next" | "page-last" | "entries-per-site" | "page-current" | "page-selected" | "page-per-site" | "logo-description" | "open-link-in-tab" | "kolibri-logo", "symbol" | "abbr" | "accordion" | "accordion-group" | "alert" | "avatar" | "badge" | "breadcrumb" | "button" | "button-group" | "button-link" | "card" | "details" | "form" | "heading" | "icon" | "image" | "indented-text" | "input-checkbox" | "input-color" | "input-date" | "input-email" | "input-file" | "input-number" | "input-password" | "input-radio" | "input-range" | "input-text" | "kolibri" | "link" | "link-button" | "link-group" | "logo" | "modal" | "nav" | "pagination" | "progress" | "select" | "separator" | "skip-nav" | "spin" | "split-button" | "table" | "table-stateless" | "table-stateful" | "tabs" | "textarea" | "toast-container" | "toolbar" | "tooltip" | "tree" | "tree-item">;

export { AbbrAPI, AbbrProps, AbbrStates, AccessKeyPropType, AccordionAPI, AccordionProps, AccordionStates, ActivePropType, AdjustHeightPropType, AlertAPI, AlertPropType, AlertProps, AlertStates, AlertType, AlertVariant, AlignPropType, AlternativeButtonLinkRolePropType, AnyIconFontClass, AriaCurrentValuePropType, AvatarAPI, AvatarProps, AvatarStates, BadgeAPI, BadgeProps, BadgeStates, BreadcrumbAPI, BreadcrumbLinkProps, BreadcrumbProps, BreadcrumbStates, ButtonAPI, ButtonCallbacksPropType, ButtonGroupAPI, ButtonGroupProps, ButtonGroupStates, ButtonLinkProps, ButtonLinkStates, ButtonOrLinkOrTextWithChildrenProps, ButtonProps, ButtonStates, ButtonTypePropType, ButtonVariantPropType, ButtonWithChildrenProps, CSSResize, CardAPI, CardProps, CardStates, CheckedPropType, CollapsiblePropType, ColorContrast, ColorPair, CustomClassPropType, DetailsAPI, DetailsProps, DetailsStates, DisabledPropType, DownloadPropType, ErrorListPropType, EventCallback, EventCallbacks, EventValueOrEventCallback, FormAPI, FormProps, FormStates, HasCloserPropType, HasCounterPropType, HasIconsWhenExpandedPropType, HeadingAPI, HeadingLevel, HeadingProps, HeadingStates, HeadingVariantPropType, HideErrorPropType, HideLabelPropType, HrefProp, HrefPropType, IconAPI, IconProps, IconStates, IconsPropType, IdPropType, ImageAPI, ImageProps, ImageSourcePropType, ImageStates, IndentedTextAPI, IndentedTextProps, IndentedTextStates, IndeterminatePropType, InputCheckboxAPI, InputCheckboxIconsProp, InputCheckboxIconsState, InputCheckboxProps, InputCheckboxStates, InputCheckboxVariant, InputCheckboxWatches, InputColorAPI, InputColorProps, InputColorStates, InputColorWatches, InputDateAPI, InputDateProps, InputDateStates, InputDateType, InputDateWatches, InputEmailAPI, InputEmailProps, InputEmailStates, InputEmailWatches, InputFileAPI, InputFileProps, InputFileStates, InputFileWatches, InputNumberAPI, InputNumberProps, InputNumberStates, InputNumberWatches, InputPasswordAPI, InputPasswordProps, InputPasswordStates, InputPasswordWatches, InputProps, InputRadioAPI, InputRadioProps, InputRadioStates, InputRadioWatches, InputRangeAPI, InputRangeProps, InputRangeStates, InputRangeWatches, InputTextAPI, InputTextProps, InputTextStates, InputTextType, InputTextWatches, InputTypeOnDefault, InputTypeOnOff, Iso8601, KoliBri, KoliBriAccordionCallbacks, KoliBriAlertEventCallbacks, KoliBriAllIcons, KoliBriCardEventCallbacks, KoliBriCustomIcon, KoliBriDataCompareFn, KoliBriDevHelper, KoliBriFormCallbacks, KoliBriHorizontalIcons, KoliBriIconsProp, KoliBriIconsState, KoliBriModalEventCallbacks, KoliBriPaginationButtonCallbacks, KoliBriPaginationProps, KoliBriProgressVariantEnum, KoliBriProgressVariantType, KoliBriQuoteVariant, KoliBriSortDirection, KoliBriSortFunction, KoliBriTableCell, KoliBriTableCellTextAlign, KoliBriTableDataType, KoliBriTableHeaderCell, KoliBriTableHeaderCellAndData, KoliBriTableHeaderCellWithLogic, KoliBriTableHeaders, KoliBriTablePaginationProps, KoliBriTableRender, KoliBriTableSelectedHead, KoliBriTabsCallbacks, KoliBriUtils, KolibriAPI, KolibriProps, KolibriStates, LabelProp, LabelPropType, LabelWithExpertSlotPropType, LinkAPI, LinkButtonProps, LinkGroupAPI, LinkGroupProps, LinkGroupStates, LinkOnCallbacksPropType, LinkProps, LinkStates, LinkTargetPropType, LinkWithChildrenProps, ListStyleType, Loading, Log, Logger, MaxPropType, ModalAPI, ModalProps, ModalStates, MsgPropType, MultiplePropType, NamePropType, NavAPI, NavProps, NavStates, OpenPropType, Optgroup, Option, OptionalButtonProps, OptionalButtonStates, OptionalInputProps, OptionalProps$J as OptionalProps, OptionsPropType, OptionsWithOptgroupPropType, Orientation, PaginationAPI, PaginationHasButton, PaginationPositionPropType, PaginationProps, PaginationStates, PopoverAPI, PopoverProps, PopoverStates, ProgressAPI, ProgressProps, ProgressStates, PropAccessKey, PropActive, PropAdjustHeight, PropAlert, PropAlign, PropAlternativeButtonLinkRole, PropAriaControls, PropAriaCurrentValue, PropAriaExpanded, PropAriaSelected, PropButtonCallbacks, PropButtonType, PropButtonVariant, PropChecked, PropCollapsible, PropColor, PropCustomClass, PropDisabled, PropDownload, PropErrorList, PropHasCloser, PropHasCompactButton, PropHasCounter, PropHasIconsWhenExpanded, PropHeadingVariant, PropHideError, PropHideLabel, PropHref, PropIcons, PropId, PropImageSource, PropIndeterminate, PropLabel, PropLabelWithExpertSlot, PropLinkOnCallbacks, PropLinkTarget, PropMax, PropMsg, PropMultiple, PropName, PropOpen, PropOptions, PropOptionsWithOptgroup, PropPaginationPosition, PropReadOnly, PropRequired, PropRows, PropShow, PropSpinVariant, PropSuggestions, PropSyncValueBySelector, PropTableCallbacks, PropTableData, PropTableDataFoot, PropTableHeaderCells, PropTooltipAlign, PropTouched, QuoteAPI, QuoteProps, QuoteStates, ReadOnlyPropType, RequiredButtonProps, RequiredButtonStates, RequiredProps$J as RequiredProps, RowsPropType, STATE_CHANGE_EVENT, SelectAPI, SelectOption, SelectProps, SelectStates, SelectWatches, SetStateHooks, ShowPropType, SkipNavAPI, SkipNavProps, SkipNavStates, SortEventPayload, SpanAPI, SpanProps, SpanStates, SpinAPI, SpinProps, SpinStates, SpinVariantPropType, SplitButtonAPI, SplitButtonProps, SplitButtonStates, StencilUnknown, Stringified, SuggestionsPropType, SymbolAPI, SymbolProps, SymbolStates, SyncValueBySelectorPropType, TabButtonProps, TableAPI, TableCallbacksPropType, TableDataFootPropType, TableDataPropType, TableHeaderCells, TableHeaderCellsPropType, TableProps, TableStatelessAPI, TableStatelessProps, TableStatelessStates, TableStates, TabsAPI, TabsProps, TabsStates, TextareaAPI, TextareaProps, TextareaStates, TextareaWatches, Toast, ToastRenderFunction, ToastState, ToasterAPI, ToasterOptions, ToasterProps, ToasterStates, TooltipAPI, TooltipAlignPropType, TooltipProps, TooltipStates, TouchedPropType, TreeAPI, TreeItemAPI, TreeItemProps, TreeItemStates, TreeProps, TreeStates, VersionAPI, VersionProps, VersionStates, W3CInputValue, WatchBooleanOptions, WatchNumberOptions, WatchOptions, WatchStringOptions, a11yHint, a11yHintDisabled, a11yHintLabelingLandmarks, alertTypeOptions, alertVariantOptions, alignPropTypeOptions, calcColorContrast, containsOnlyNumbers, createContrastColorPair, cssResizeOptions, devHint, devWarning, emptyStringByArrayHandler, featureHint, getColorContrast, getColorContrastAnalysis, getContrastYIQ, getDevMode, getDocument, getExperimentalMode, getWindow, handleColorChange, handleSlotContent, hasEnoughReadableChars, headingLevelOptions, inputCheckboxVariantOptions, inputDateTypeOptions, inputTextTypeOptions, inputTypeOnOffOptions, isIcon, isObject, isString, isStyle, koliBriA11yColorContrast, koliBriQuerySelector, koliBriQuerySelectorAll, koliBriQuerySelectorColors, koliBriQuoteVariantOptions, mapBoolean2String, mapIconProp2State, mapString2Unknown, mapStringOrBoolean2String, objectObjectHandler, orientationOptions, parseJson, processEnv, propagateFocus, setColorContrastAnalysis, setDevMode, setDocument, setEventTarget, setExperimentalMode, setState, setWindow, showExpertSlot, stringifyJson, uiUxHint, uiUxHintMillerscheZahl, validateAccessKey, validateActive, validateAdjustHeight, validateAlert, validateAlign, validateAlignment, validateAlternativeButtonLinkRole, validateAriaControls, validateAriaCurrentValue, validateAriaExpanded, validateAriaSelected, validateButtonCallbacks, validateButtonType, validateButtonVariant, validateChecked, validateCollapsible, validateColor, validateCustomClass, validateDisabled, validateDownload, validateErrorList, validateHasCloser, validateHasCompactButton, validateHasCounter, validateHasIconsWhenExpanded, validateHeadingVariant, validateHideError, validateHideLabel, validateHref, validateIcons, validateId, validateImageSource, validateIndeterminate, validateInputSelectOptions, validateLabel, validateLabelWithExpertSlot, validateLinkCallbacks, validateLinkTarget, validateLoading, validateMax, validateMsg, validateMultiple, validateName, validateOpen, validateOptions, validateOptionsWithOptgroup, validatePaginationPosition, validateReadOnly, validateRequired, validateRows, validateShow, validateSpinVariant, validateSuggestions, validateTabIndex, validateTableCallbacks, validateTableData, validateTableDataFoot, validateTableHeaderCells, validateTooltipAlign, validateTouched, watchBoolean, watchJsonArrayString, watchNumber, watchString, watchValidator };
